@@ -10,10 +10,8 @@ CAMERA_MESSAGES = [
     "DISARM_C",
     "ARM_M",
     "DISARM_M",
-    "OFFLINE",
-    "ONLINE",
 ]
-EVENT_MESSAGES = ["TRIGGER_M", "MOTION", "CLASSIFY", "MOTION_END"]
+EVENT_MESSAGES = ["TRIGGER_M", "MOTION", "CLASSIFY", "MOTION_END", "ONLINE", "OFFLINE"]
 
 RECORDING_TYPE_ACTION = "action"
 RECORDING_TYPE_MOTION = "on_motion"
