@@ -37,8 +37,9 @@ PROCESSED_EVENT_EMPTY = {
     "event_type": None,
     "event_online": True,
     "event_length": 0,
-    "event_object": [],
-    "event_score": 0,
+    "event_object": None,
+    "event_score_human": 0,
+    "event_score_vehicle": 0,
 }
 
 REASON_CODES = {"128": "Human", "256": "Vehicle"}
@@ -241,10 +242,14 @@ def process_event(event):
     event_type = event.get("type")
     event_reason = event.get("reason")
     event_online = event.get("isOnline")
-    if not event.get("event_score"):
-        event_score = 0
+    if not event.get("event_score_human"):
+        event_score_human = 0
     else:
-        event_score = event.get("event_score")
+        event_score_human = event.get("event_score_human")
+    if not event.get("event_score_vehicle"):
+        event_score_vehicle = 0
+    else:
+        event_score_vehicle = event.get("event_score_vehicle")
 
     event_length = 0
     start_time = None
@@ -266,7 +271,8 @@ def process_event(event):
         "event_start": start_time,
         "event_length": event_length,
         "event_object": event_object,
-        "event_score": event_score,
+        "event_score_human": event_score_human,
+        "event_score_vehicle": event_score_vehicle,
         "event_online": event_online,
     }
 
